@@ -15,7 +15,10 @@
 ##
 #################################################################################
 .onLoad <- function(lib, pkg) {
-	if(interactive() || getOption("verbose")) packageStartupMessage(sprintf("Package %s (%s) loaded.  To cite, see citation(\"%s\")\n", pkg, utils::packageDescription(pkg)$Version, pkg))
+	if(interactive() || getOption("verbose"))
+		packageStartupMessage(sprintf(
+						"Package %s (%s) loaded.  To cite, see citation(\"%s\")\n",
+						pkg, utils::packageDescription(pkg)$Version, pkg))
 }
 
 .onUnload<-function(libpath)
